@@ -5,7 +5,6 @@
 
 from flask import render_template, redirect, url_for,send_from_directory, current_app, abort
 from flask import jsonify
-from iatoolkit.views.history_api_view import HistoryApiView
 
 
 # this function register all the views
@@ -24,13 +23,19 @@ def register_views(injector, app):
     from iatoolkit.views.file_store_api_view import FileStoreApiView
     from iatoolkit.views.user_feedback_api_view import UserFeedbackApiView
     from iatoolkit.views.prompt_api_view import PromptApiView
+    from iatoolkit.views.history_api_view import HistoryApiView
+    from iatoolkit.views.help_content_api_view import HelpContentApiView
+
     from iatoolkit.views.login_view import LoginView, FinalizeContextView
     from iatoolkit.views.external_login_view import ExternalLoginView, RedeemTokenApiView
     from iatoolkit.views.logout_api_view import LogoutApiView
-
+    from iatoolkit.views.home_view import HomeView
 
     # iatoolkit home page
-    app.add_url_rule('/<company_short_name>', view_func=IndexView.as_view('index'))
+    app.add_url_rule('/', view_func=IndexView.as_view('index'))
+
+    # company home view
+    app.add_url_rule('/<company_short_name>/home', view_func=HomeView.as_view('home'))
 
     # login for the iatoolkit integrated frontend
     app.add_url_rule('/<company_short_name>/login', view_func=LoginView.as_view('login'))
@@ -76,9 +81,10 @@ def register_views(injector, app):
     # open the promt directory
     app.add_url_rule('/<company_short_name>/api/prompts', view_func=PromptApiView.as_view('prompt'))
 
-    # feedback and history
+    # toolbar buttons
     app.add_url_rule('/<company_short_name>/api/feedback', view_func=UserFeedbackApiView.as_view('feedback'))
     app.add_url_rule('/<company_short_name>/api/history', view_func=HistoryApiView.as_view('history'))
+    app.add_url_rule('/<company_short_name>/api/help-content', view_func=HelpContentApiView.as_view('help-content'))
 
     # tasks management endpoints: create task, and review answer
     app.add_url_rule('/tasks', view_func=TaskApiView.as_view('tasks'))
@@ -124,6 +130,6 @@ def register_views(injector, app):
     # hacer que la raíz '/' vaya al home de iatoolkit
     @app.route('/')
     def root_redirect():
-        return redirect(url_for('index', company_short_name='sample_company'))
+        return redirect(url_for('index'))
 
 
