@@ -60,7 +60,7 @@ class Company(Base):
 
     branding = Column(JSON, nullable=True)
     onboarding_cards = Column(JSON, nullable=True)
-    parameters = Column(JSON, nullable=True, default={})
+    parameters = Column(JSON, nullable=True)
     created_at = Column(DateTime, default=datetime.now)
     allow_jwt = Column(Boolean, default=True, nullable=True)
 
