@@ -4,10 +4,10 @@
 # IAToolkit is open source software.
 
 from flask.views import MethodView
-from flask import request, redirect, render_template, url_for
+from flask import (request, redirect, render_template, url_for,
+                   render_template_string, flash)
 from injector import inject
 from iatoolkit.services.profile_service import ProfileService
-from iatoolkit.services.auth_service import AuthService
 from iatoolkit.services.jwt_service import JWTService
 from iatoolkit.services.query_service import QueryService
 from iatoolkit.services.prompt_manager_service import PromptService
@@ -25,8 +25,11 @@ class LoginView(BaseLoginView):
     def post(self, company_short_name: str):
         company = self.profile_service.get_company_by_short_name(company_short_name)
         if not company:
-            return render_template('error.html', message="Empresa no encontrada"), 404
+            return render_template('error.html',
+                        company_short_name=company_short_name,
+                        message="Empresa no encontrada"), 404
 
+        branding_data = self.branding_service.get_company_branding(company)
         email = request.form.get('email')
         password = request.form.get('password')
 
@@ -38,15 +41,15 @@ class LoginView(BaseLoginView):
         )
 
         if not auth_response['success']:
-            branding_data = self.branding_service.get_company_branding(company)
+            flash(auth_response["message"], 'error')
+            home_template = self.utility.get_company_template(company_short_name, "home.html")
 
-            return render_template(
-                'index.html',
+            return render_template_string(
+                home_template,
                 company_short_name=company_short_name,
                 company=company,
                 branding=branding_data,
                 form_data={"email": email},
-                alert_message=auth_response["message"]
             ), 400
 
         user_identifier = auth_response['user_identifier']
@@ -60,8 +63,10 @@ class LoginView(BaseLoginView):
         try:
             return self._handle_login_path(company, user_identifier, target_url)
         except Exception as e:
-            return render_template("error.html", company=company, company_short_name=company_short_name,
-                                   message=f"Error processing login path: {str(e)}"), 500
+            return render_template("error.html",
+            company_short_name=company_short_name,
+            branding=branding_data,
+            message=f"Error processing login path: {str(e)}"), 500
 
 
 class FinalizeContextView(MethodView):
@@ -72,7 +77,6 @@ class FinalizeContextView(MethodView):
     @inject
     def __init__(self,
                  profile_service: ProfileService,
-                 auth_service: AuthService,
                  query_service: QueryService,
                  prompt_service: PromptService,
                  branding_service: BrandingService,
@@ -97,16 +101,19 @@ class FinalizeContextView(MethodView):
             payload = self.jwt_service.validate_chat_jwt(token)
             if not payload:
                 logging.warning("Fallo crítico: No se pudo leer el auth token.")
-                return redirect(url_for('index', company_short_name=company_short_name))
+                return redirect(url_for('home', company_short_name=company_short_name))
 
             user_identifier = payload.get('user_identifier')
         else:
             logging.warning("Fallo crítico: missing session information or auth token")
-            return redirect(url_for('index', company_short_name=company_short_name))
+            return redirect(url_for('home', company_short_name=company_short_name))
 
         company = self.profile_service.get_company_by_short_name(company_short_name)
         if not company:
-            return render_template('error.html', message="Empresa no encontrada"), 404
+            return render_template('error.html',
+                        company_short_name=company_short_name,
+                        message="Empresa no encontrada"), 404
+        branding_data = self.branding_service.get_company_branding(company)
 
         try:
             # 2. Finalize the context rebuild (the heavy task).
@@ -117,7 +124,6 @@ class FinalizeContextView(MethodView):
 
             # 3. render the chat page.
             prompts = self.prompt_service.get_user_prompts(company_short_name)
-            branding_data = self.branding_service.get_company_branding(company)
             onboarding_cards = self.onboarding_service.get_onboarding_cards(company)
 
             return render_template(
@@ -132,7 +138,7 @@ class FinalizeContextView(MethodView):
 
         except Exception as e:
             return render_template("error.html",
-                                   company=company,
                                    company_short_name=company_short_name,
+                                   branding=branding_data,
                                    message=f"An unexpected error occurred during context loading: {str(e)}"), 500
 
