@@ -4,9 +4,9 @@
 # IAToolkit is open source software.
 
 from flask.views import MethodView
-from flask import render_template, request, url_for, session, redirect
+from flask import render_template, request, url_for, redirect, flash
 from iatoolkit.services.profile_service import ProfileService
-from iatoolkit.services.branding_service import BrandingService # 1. Importar BrandingService
+from iatoolkit.services.branding_service import BrandingService
 from injector import inject
 from itsdangerous import URLSafeTimedSerializer
 import os
@@ -25,7 +25,9 @@ class SignupView(MethodView):
         # get company info
         company = self.profile_service.get_company_by_short_name(company_short_name)
         if not company:
-            return render_template('error.html', message="Empresa no encontrada"), 404
+            return render_template('error.html',
+                            company_short_name=company_short_name,
+                            message="Empresa no encontrada"), 404
 
         # Obtener los datos de branding
         branding_data = self.branding_service.get_company_branding(company)
@@ -39,8 +41,11 @@ class SignupView(MethodView):
         # get company info
         company = self.profile_service.get_company_by_short_name(company_short_name)
         if not company:
-            return render_template('error.html', message="Empresa no encontrada"), 404
+            return render_template('error.html',
+                        company_short_name=company_short_name,
+                        message="Empresa no encontrada"), 404
 
+        branding_data = self.branding_service.get_company_branding(company)
         try:
             first_name = request.form.get('first_name')
             last_name = request.form.get('last_name')
@@ -62,7 +67,7 @@ class SignupView(MethodView):
                 verification_url=verification_url)
 
             if "error" in response:
-                branding_data = self.branding_service.get_company_branding(company)
+                flash(response["error"], 'error')
                 return render_template(
                     'signup.html',
                     company=company,
@@ -74,19 +79,14 @@ class SignupView(MethodView):
                         "email": email,
                         "password": password,
                         "confirm_password": confirm_password
-                    },
-                    alert_message=response["error"]), 400
+                    }), 400
 
-            # Guardamos el mensaje de éxito en la sesión
-            session['alert_message'] = response["message"]
-            session['alert_icon'] = 'success'
-
-            # Redirigimos al usuario a la página de login
-            return redirect(url_for('index', company_short_name=company_short_name))
+            flash(response["message"], 'success')
+            return redirect(url_for('home', company_short_name=company_short_name))
 
         except Exception as e:
             return render_template("error.html",
-                                   company=company,
                                    company_short_name=company_short_name,
-                                   message="Ha ocurrido un error inesperado."), 500
+                                   branding=branding_data,
+                                   message=f"Ha ocurrido un error inesperado: {str(e)}"), 500
 
